SciSalt
=======

This project has slowly grown from frequently-used code snippets. The
main objective is to create a collection of interconnected methods
frequently needed to visualize and analyze data using Numpy, Scipy,
Matplotlib, and PyQt.
